@@ -2,12 +2,8 @@ from os import system
 from grepsrcli.core.message_log import Log
 from cement import Controller, ex
 import pkg_resources
-import platform
 from grepsrcli.core.sdk_setup import SDKSetup
 from grepsrcli.core.config import save_config
-from grepsrcli.core.UI.app import load_ui
-
-
 
 
 version = pkg_resources.require("grepsr-cli")[0].version
@@ -50,20 +46,10 @@ class Base(Controller):
     @ex(help="Update configuration for gcli",
         arguments=[
             (['--update'], {'action': 'store_true',  'dest': 'update'}),
-            (['--gui'], {'action': 'store_true',  'dest': 'gui'}),
-            (['--port'], {'action': 'store',  'dest': 'port'})
         ]
         )
     def configure(self):
-        
-                
-        if self.app.pargs.gui == False:
-            if(self.app.pargs.update == True):
-                save_config(update=True)
-            else:
-                save_config(update=False)
+        if(self.app.pargs.update == True):
+            save_config(update=True)
         else:
-            port = self.app.pargs.port
-            if not port:
-                port = 5000
-            load_ui(port)
+            save_config(update=False)
\ No newline at end of file
