@@ -1,8 +1,9 @@
-from os import makedirs, system, path, stat
-import subprocess
+from os import system, path
+import sys
 import time
+import subprocess
 import pathlib
-from semver import VersionInfo, process
+from semver import VersionInfo
 from cement import Controller, ex
 from ..core.config import load_config
 from ..core.utils import create_boilerplate, render_boilerplate, get_plugin_info, get_plugin_path, show_schema
@@ -26,6 +27,7 @@ class Crawler(Controller):
 
     @ex(
         help="test a plugin locally",
+        aliases=['tst'],
         arguments=[
             (['-s'], {
                 'action': 'store',
@@ -38,12 +40,11 @@ class Crawler(Controller):
 
         plugin_name = self.app.pargs.plugin_name
 
-        if get_plugin_path(plugin_name, type='php'):
+        if get_plugin_path(plugin_name, type='php') if 'php' in self.config else False:
             base_path = pathlib.Path(get_plugin_path(
                 plugin_name, type='php')).parent
             TestLocal('php', plugin_name, base_path)
-        elif get_plugin_path(plugin_name, type='php_next'):
-
+        elif get_plugin_path(plugin_name, type='php_next') if 'php_next' in self.config else False:
             base_path = pathlib.Path(get_plugin_path(
                 plugin_name, type='php_next')).parent
             TestLocal('php_next', plugin_name, base_path)
@@ -174,6 +175,9 @@ class Crawler(Controller):
         ]
     )
     def deploy(self):
+
+        toolbar_width = 50
+
         input_plugin_name = self.app.pargs.plugin_name
         deploy_message = self.app.pargs.message
 
@@ -203,15 +207,13 @@ class Crawler(Controller):
             plugin_names.append(input_plugin_name)
 
         for plugin_name in plugin_names:
-            print(f'Deploying: {plugin_name} ')
 
             plugin_name = plugin_name.strip()
-
             plugin_dir_path = get_plugin_path(plugin_name, all_types=True)
 
             if(plugin_dir_path):
-
                 plugin_info = get_plugin_info(plugin_dir_path)
+                # add .version or update .version
                 version_path = '{}/.version'.format(plugin_dir_path)
                 if(path.exists(version_path)):
                     with open(version_path, 'r') as f:
@@ -244,6 +246,17 @@ class Crawler(Controller):
 
                     self.app.log.info(
                         "[{}] [{}] {}".format(deploy_type, version_info, deploy_message))
+                
+                if self.app.pargs.verbose is False:
+                    sys.stdout.write(
+                        "Deploying: [%s]" % (" " * toolbar_width))
+                    sys.stdout.flush()
+                    sys.stdout.write("\b" * (toolbar_width+1))
+
+                    progress = int(.10 * toolbar_width)
+                    sys.stdout.write("-" * progress)
+                    sys.stdout.flush()
+                    time.sleep(.5)
                 try:
                     cmd = f"""
                         cd {plugin_dir_path} &&
@@ -267,17 +280,32 @@ class Crawler(Controller):
                         git commit -m "[{deploy_type}] [{version_info}] {deploy_message}" &&
                         git push origin master
                         """
+                    if self.app.pargs.verbose is False:
+                        progress = int(.40 * toolbar_width)
+                        sys.stdout.write("-" * progress)
+                        sys.stdout.flush()
 
                     subprocess.run(
                         cmd, shell=True, check=True)
+                    if self.app.pargs.verbose is False:
+                        progress = int(.30 * toolbar_width)
+                        sys.stdout.write("-" * progress)
+                        sys.stdout.flush()
+                        time.sleep(.5)
 
                 except subprocess.CalledProcessError:
                     self.app.log.error(
                         f'There was a problem deploying {plugin_name}')
                     return
 
+                if self.app.pargs.verbose is False:
+                    progress = int(.20 * toolbar_width)
+                    sys.stdout.write("-" * progress)
+                    sys.stdout.flush()
+                    sys.stdout.write("]\n")
+
                 show_schema(plugin_dir_path)
-                # sleep for a while to fake a real deployment.
+
                 try:
                     app_url = f'https://appnext.grepsr.com/projects/{plugin_info["pid"]}'
                     self.app.log.info(f"App Url: {app_url}")
@@ -306,7 +334,8 @@ class Crawler(Controller):
     )
     def use_basecrawler(self):
 
-        s3 = S3()
+        s3 = S3(aws_id=self.config['aws_access_key_id'],
+                aws_sec_key=self.config['aws_secret_access_key'])
 
         version = None
         base_plugin_name = self.app.pargs.base_plugin_name
@@ -345,6 +374,7 @@ class Crawler(Controller):
 
             presigned_url = s3.get_secure_url(bucket='crawler-plugins',
                                               filename=f'php/vortex-plugins-services-base/{base_plugin_name}/{base_plugin_name}-{version}.tar.gz')
+
             data = {
                 'presigned_url': presigned_url,
                 'plugin_name': base_plugin_name,
